﻿using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.DataPresenter.Events;

namespace IgTestGrid
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {

        #region collection view sources

        private CollectionViewSource cvsDataGrid;
        private CollectionViewSource cvsTaskList;
        private CollectionViewSource cvsPickList1;
        private CollectionViewSource cvsPickList2;
        private CollectionViewSource cvsPickList12;
        #endregion

        private bool _isLoading = true;

        public MainWindow()
        {
            InitializeComponent();
            InitializeTaskList();
        }

        private void MainWindow_OnLoaded(object sender, RoutedEventArgs e)
        {
            var task = cboTable.SelectedValue.ToString();
            SetNextTask(task);
            _isLoading = false;
        }

        private void GrdMaint_OnFieldLayoutInitialized(object sender, FieldLayoutInitializedEventArgs e)
        {
            //
            foreach (Field fld in e.FieldLayout.Fields)
            {
                fld.Settings.AllowEdit = false;
            }

            var task = cboTable.SelectedValue.ToString();
            switch (task.ToUpper())
            {
                case "CLASS1":
                    Field eField1 = e.FieldLayout.Fields["Notes"];
                    eField1.Settings.AllowEdit = true;
                    eField1.Settings.CellValuePresenterStyle = Resources["EditableColumn"] as Style;

                    Field nFld = e.FieldLayout.Fields["Nmix"];
                    nFld.Settings.CellValuePresenterStyle = Resources["DropDownPicker1"] as Style;

                    Field rnFld = e.FieldLayout.Fields["Rmix"];
                    rnFld.Settings.CellValuePresenterStyle = Resources["DropDownPicker12"] as Style;
                    break;
                case "CLASS2":
                    Field eField2 = e.FieldLayout.Fields["Rate"];
                    eField2.Settings.AllowEdit = true;
                    eField2.Settings.CellValuePresenterStyle = Resources["EditableColumn"] as Style;

                    Field rFld = e.FieldLayout.Fields["Rmix"];
                    rFld.Settings.CellValuePresenterStyle = Resources["DropDownPicker2"] as Style;
                    break;
                case "CLASS3":
                    Field eField3 = e.FieldLayout.Fields["Effort"];
                    eField3.Settings.AllowEdit = true;
                    eField3.Settings.CellValuePresenterStyle = Resources["EditableColumn"] as Style;
                    break;                    
            }

        }

        private void CboTable_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (_isLoading) return;
            var task = cboTable.SelectedValue.ToString();
            SetNextTask(task);
        }

        #region methods

        private void InitializeTaskList()
        {
            var myList = new ObservableCollection<string>(new List<string> {"Class1", "Class2", "Class3"});

            cvsTaskList = (CollectionViewSource)FindResource("cvsTaskList");
            cvsTaskList.Source = myList;
        }

        private ObservableCollection<Class1> GetClass1Data()
        {
            var list = new List<Class1>
            {
                new Class1
                {
                    Id = "1",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "2",
                    DisplayLabel = "Waffles",
                    Notes = "We need more!",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "3",
                    DisplayLabel = "Bacon",
                    Notes = "The perfect gift...",
                    Nmix = "",
                    Rmix = ""
                },

                new Class1
                {
                    Id = "4",
                    DisplayLabel = "Cornbread",
                    Notes = "Not a Lot of notes",
                    Nmix = "2",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "5",
                    DisplayLabel = "Lasagna",
                    Notes = "Lots o notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "6",
                    DisplayLabel = "Rhubarb pie",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "7",
                    DisplayLabel = "Junk food",
                    Notes = "Lots notes",
                    Nmix = "",
                    Rmix = ""
                },


                new Class1
                {
                    Id = "8",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "9",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "10",
                    DisplayLabel = "Blubber",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "11",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "12",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },

                new Class1
                {
                    Id = "13",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "14",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "15",
                    DisplayLabel = "Fishsticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "16",
                    DisplayLabel = "Fishotica",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "17",
                    DisplayLabel = "Harbloons",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "18",
                    DisplayLabel = "Bricks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "19",
                    DisplayLabel = "Sticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                },
                new Class1
                {
                    Id = "20",
                    DisplayLabel = "Ticks",
                    Notes = "Lots of notes",
                    Nmix = "",
                    Rmix = ""
                }

            };

            return new ObservableCollection<Class1>(list);
        }

        private ObservableCollection<Class2> GetClass2Data()
        {
            var list = new List<Class2>
            {
                new Class2
                {
                    Id = "1",
                    DisplayLabel = "Fishing",
                    Rate = "3.00",
                    Rmix = ""
                },
                new Class2
                {
                    Id = "2",
                    DisplayLabel = "Baking",
                    Rate = "4.00",
                    Rmix = ""
                },
                new Class2
                {
                    Id = "3",
                    DisplayLabel = "Pigs",
                    Rate = "5.00",
                    Rmix = ""
                }
            };
            return new ObservableCollection<Class2>(list);
        }

        private ObservableCollection<Class3> GetClass3Data()
        {
            var list = new List<Class3>
            {
                new Class3
                {
                    Id = "1",
                    DisplayLabel = "Stones",
                    Effort = "40"
                },
                new Class3
                {
                    Id = "2",
                    DisplayLabel = "Cones",
                    Effort = "20"
                },
                new Class3
                {
                    Id = "3",
                    DisplayLabel = "Phones",
                    Effort = "45"
                }
            };
            return new ObservableCollection<Class3>(list);
        }

        private void SetNextTask(string pTask)
        {
            switch (pTask.ToUpper())
            {
                case "CLASS1":
                    LoadClass1();
                    break;
                case "CLASS2":
                    LoadClass2();
                    break;
                case "CLASS3":
                    LoadClass3();
                    break;
            }
        }

        private void LoadClass1()
        {
            cvsDataGrid = (CollectionViewSource) FindResource("cvsDataGrid");
            cvsDataGrid.Source = GetClass1Data();

            cvsPickList1 = (CollectionViewSource)FindResource("cvsPickList1");
            cvsPickList1.Source = Lookups.GetNmixLookups();

            cvsPickList12 = (CollectionViewSource)FindResource("cvsPickList12");
            cvsPickList12.Source = Lookups.GetRmixLookups();

        }

        private void LoadClass2()
        {
            cvsDataGrid = (CollectionViewSource)FindResource("cvsDataGrid");
            cvsDataGrid.Source = GetClass2Data();

            cvsPickList2 = (CollectionViewSource)FindResource("cvsPickList2");
            cvsPickList2.Source = Lookups.GetRmixLookups();

        }

        private void LoadClass3()
        {
            cvsDataGrid = (CollectionViewSource)FindResource("cvsDataGrid");
            cvsDataGrid.Source = GetClass3Data();
        }
        #endregion
    }
}

